@@ -40,7 +40,7 @@
 PYBIND11_MODULE(_muFFT, mod) {
   mod.doc() = "Python bindings to the µFFT library";
 
-  add_common(mod);
+  add_common_mufft(mod);
   add_derivatives(mod);
   add_fft_engines(mod);
 }
