@@ -383,15 +383,10 @@ namespace muGrid {
   bool FieldCollection::is_initialised() const { return this->initialised; }
 
   /* ---------------------------------------------------------------------- */
-  auto FieldCollection::get_pixel_indices_fast() const -> PixelIndexIterable {
+  auto FieldCollection::get_pixel_indices() const -> PixelIndexIterable {
     return PixelIndexIterable{*this};
   }
 
-  /* ---------------------------------------------------------------------- */
-  auto FieldCollection::get_pixel_indices() const -> IndexIterable {
-    return IndexIterable{*this};
-  }
-
   /* ---------------------------------------------------------------------- */
   auto FieldCollection::get_sub_pt_indices(const std::string & tag) const
       -> IndexIterable {
@@ -664,12 +659,12 @@ namespace muGrid {
   std::ostream &
   operator<<(std::ostream & os,
              const muGrid::FieldCollection::ValidityDomain & value) {
-    const char* s = 0;
+    const char * s = 0;
     switch (value) {
     case (muGrid::FieldCollection::ValidityDomain::Global):
       s = "ValidityDomain::Global";
       break;
-    case(muGrid::FieldCollection::ValidityDomain::Local):
+    case (muGrid::FieldCollection::ValidityDomain::Local):
       s = "ValidityDomain::Local";
       break;
     default:
